Input processor
===============
.. currentmodule:: biobroker.input_processor

.. autosummary::
   :nosignatures:

    GenericInputProcessor
    TsvInputProcessor
    XlsxInputProcessor

.. automodule:: biobroker.input_processor
   :members:
   :undoc-members:
   :show-inheritance:


Exceptions
----------

.. automodule:: biobroker.input_processor.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
